@@ -10,10 +10,11 @@ STALENESS_THRESHOLD_IN_SECS: int = 60 * 60
 
 
 @dataclass
-class FileInfo:
+class FileMetadata:
     """An imported file including meta data"""
     data: PackagesMetadataList | None = None
-    name: str = None
+    version: str | None = None
+    name: str | None = None
     host: str | None = None
     package_manager: str | None = None
     verb: str | None = None
