@@ -1,3 +1,3 @@
 #!/usr/bin/env python
 """Helper for loading omniversion files"""
-from .loader import load_data, load_file
+from .loader import load_data
